@@ -5,7 +5,7 @@
 modname = 'cubicweb_jsonschema'
 distname = 'cubicweb-jsonschema'
 
-numversion = (0, 2, 7)
+numversion = (0, 2, 11)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -15,11 +15,10 @@ description = 'JSON Schema for CubicWeb'
 web = 'https://www.cubicweb.org/project/%s' % distname
 
 __depends__ = {
-    'cubicweb[pyramid]': '>= 3.26.19',
-    'six': '>= 1.12.0',
+    'cubicweb': '>= 3.37.2, < 3.39.0',
     'iso8601': None,
     'jsl': None,
-    'pyramid': '>= 1.10.0',
+    'pyramid': '>= 1.10.8',
 }
 __recommends__ = {}
 
@@ -27,5 +26,7 @@ classifiers = [
     'Environment :: Web Environment',
     'Framework :: CubicWeb',
     'Programming Language :: Python',
+    'Programming Language :: Python :: 3',
+    'Programming Language :: Python :: 3 :: Only',
     'Programming Language :: JavaScript',
 ]
