@@ -1,5 +1,5 @@
-# copyright 2016 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-# contact http://www.logilab.fr -- mailto:contact@logilab.fr
+# copyright 2016-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact https://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -12,14 +12,13 @@
 # details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
+# along with this program. If not, see <https://www.gnu.org/licenses/>.
 """Appobjects for mapping Yams schema definitions to JSON Schema documents."""
 
 from collections import OrderedDict
 from functools import partial
 
 import iso8601
-from six import text_type, string_types
 
 import jsl
 
@@ -60,7 +59,8 @@ def yams_final_rtype(cls, cnx, rtype, role, **kwargs):
     etype = _etype_from_context(kwargs)
     if etype is None:
         return 0
-    rdef = cnx.vreg.schema[etype].rdef(rtype, role=role, takefirst=True)
+    rdef = cnx.vreg.schema[etype].relation_definition(
+        rtype, role=role, takefirst=True)
     if rdef.final:
         return 1
     return 0
@@ -81,7 +81,8 @@ def yams_component_target(cls, cnx, rtype, role, target_types=None, **kwargs):
         rschema = cnx.vreg.schema[rtype]
         target_types = tuple(t.type for t in rschema.targets(etype, role=role))
     for target_type in target_types:
-        rdef = eschema.rdef(rtype, role=role, targettype=target_type)
+        rdef = eschema.relation_definition(
+            rtype, role=role, targettype=target_type)
         _component = rdef.composite == role
         if component is None:
             component = _component
@@ -103,7 +104,7 @@ class yams_match(Predicate):
         self.etype = etype
         self.rtype = rtype
         self.role = role
-        if isinstance(target_types, string_types):
+        if isinstance(target_types, str):
             target_types = {target_types}
         elif not isinstance(target_types, (set, frozenset)):
             target_types = frozenset(target_types)
@@ -409,7 +410,7 @@ class CollectionItemMapper(JSONSchemaMapper):
         """Return a dictionary with entity represented as a collection item."""
         return {
             'type': entity.cw_etype.lower(),
-            'id': text_type(entity.eid),
+            'id': str(entity.eid),
             'title': entity.dc_title(),
         }
 
@@ -470,8 +471,9 @@ class BaseRelationMapper(JSONSchemaMapper):
         else:
             targettype = None
         eschema = self._cw.vreg.schema[self.etype]
-        rdef = eschema.rdef(self.rtype, role=self.role,
-                            targettype=targettype)
+        rdef = eschema.relation_definition(
+            self.rtype, role=self.role,
+            targettype=targettype)
         if rdef.description:
             return self._cw._(rdef.description)
 
@@ -529,7 +531,7 @@ class AttributeMapper(BaseRelationMapper):
     @property
     def attr(self):
         """Relation definition for bound attribute."""
-        return self._cw.vreg.schema[self.etype].rdef(self.rtype)
+        return self._cw.vreg.schema[self.etype].relation_definition(self.rtype)
 
     def add_constraint(self, cstr, jsl_attrs):
         serializer = self._cw.vreg['mappers'].select_or_none(
@@ -580,7 +582,7 @@ class AttributeMapper(BaseRelationMapper):
         except KeyError:
             if entity is None:
                 return {}
-            rschema = entity.e_schema.rdef(self.rtype, self.role)
+            rschema = entity.e_schema.relation_definition(self.rtype, self.role)
             value = rschema.default
         else:
             value = self._type(value)
@@ -625,7 +627,7 @@ class StringMapper(AttributeMapper):
     """Attribute mapper for Yams' String type."""
     __select__ = yams_match(target_types='String')
     jsl_field_class = jsl.fields.StringField
-    _type = text_type
+    _type = str
 
 
 class FloatMapper(AttributeMapper):
@@ -737,7 +739,7 @@ class CompoundMapper(JSONSchemaMapper):
         """name of the property to be inserted in the main JSON Schema
         document (defaults to class name).
         """
-        return text_type(cls.__name__)
+        return str(cls.__name__)
 
     @classmethod
     def __registered__(cls, reg):
@@ -855,7 +857,7 @@ class _RelationMapper(BaseRelationMapper):
             cardinalities = set([])
             rschema = self._cw.vreg.schema[self.rtype]
             for target_type in self.target_types:
-                rdef = rschema.role_rdef(
+                rdef = rschema.role_relation_definition(
                     self.etype, target_type, self.role)
                 cardinalities.add(rdef.role_cardinality(self.role))
             if len(targets) > 1:
@@ -970,10 +972,20 @@ class ETypeRelationMapper(_RelationMapper):
     def jsl_field_targets(self, schema_role):
         choices = []
         for target in self.relation_targets(schema_role):
-            choices.append((text_type(target.eid), target.dc_title()))
+            choices.append((str(target.eid), target.dc_title()))
         yield ChoiceStringField(choices, type='string')
 
     def values(self, entity, instance):
+        """
+        Handling of reverse dependant entities creation is done by returning
+        keys starting by __post_create. These keys contain a dictionary:
+        {
+            type: entity type used for creating the new entity
+            values: a dictionary for attributes passed to this new entity
+            relation: name of the relation added pointing to the main entity
+        }
+        These keys can also contain a list of such dictionaries.
+        """
         try:
             values = instance.pop(self.rtype)
         except KeyError:
@@ -987,7 +999,7 @@ class ETypeRelationMapper(_RelationMapper):
             self.rtype, self.role, targettypes=tuple(self.target_types))
         if not rset:
             return None
-        return [text_type(x.eid) for x in rset.entities()]
+        return [str(x.eid) for x in rset.entities()]
 
 
 class EntityRelationMapper(ETypeRelationMapper):
