@@ -1,5 +1,5 @@
-# copyright 2017 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-# contact http://www.logilab.fr -- mailto:contact@logilab.fr
+# copyright 2017-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact https://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -12,13 +12,10 @@
 # details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
+# along with this program. If not, see <https://www.gnu.org/licenses/>.
 """cubicweb-jsonschema's site configuration."""
 
 
-from cubicweb import __version__ as cubicweb_version
-
-
 def add_mappers_to_cube_appobject_path():
     """Add "mappers" to `cube_appobject_path` class attribute of CubicWeb
     configuration classes.
@@ -32,21 +29,12 @@ def add_mappers_to_cube_appobject_path():
     # where all known configuration modules are listed.
     # TODO: We should have a better way to discovered registered
     # configuration classes.
-    if(cubicweb_version.startswith('3.26') or
-       cubicweb_version.startswith('3.27')):
-        confs = (
-            ('etwist.twconfig', 'AllInOneConfiguration'),
-            ('server.serverconfig', 'ServerConfiguration'),
-            ('pyramid.config', 'CubicWebPyramidConfiguration'),
-            ('devtools', 'ApptestConfiguration'),
-        )
-    else:
-        confs = (
-            ('etwist.twconfig', 'AllInOneConfiguration'),
-            ('server.serverconfig', 'ServerConfiguration'),
-            ('pyramid.config', 'AllInOneConfiguration'),
-            ('devtools', 'ApptestConfiguration'),
-        )
+    confs = (
+        ('etwist.twconfig', 'AllInOneConfiguration'),
+        ('server.serverconfig', 'ServerConfiguration'),
+        ('pyramid.config', 'AllInOneConfiguration'),
+        ('devtools', 'ApptestConfiguration'),
+    )
     for confmod, configclsname in confs:
         modname = 'cubicweb.' + confmod
         try:
