@@ -12,12 +12,10 @@
 # details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
+# along with this program. If not, see <https://www.gnu.org/licenses/>.
 
 """cubicweb-jsonschema unit tests for Pyramid JSON Schema API."""
 
-from __future__ import print_function
-
 import doctest
 from functools import partial
 from glob import glob
@@ -28,7 +26,6 @@ import tempfile
 import warnings
 
 import jsonschema
-from six import PY2
 
 from cubicweb.pyramid.test import PyramidCWTest
 from cubicweb_jsonschema import testing
@@ -79,11 +76,8 @@ def load_tests(loader, tests, ignore):
                       'will be performed')
         has_ajv = False
 
-    if PY2:
-        temporary_file = tempfile.NamedTemporaryFile
-    else:
-        temporary_file = partial(tempfile.NamedTemporaryFile,
-                                 mode='w', encoding='utf-8')
+    temporary_file = partial(tempfile.NamedTemporaryFile,
+                             mode='w', encoding='utf-8')
 
     def validate_schema(schema):
         """Validate `schema` against validation and hyper meta-schema.
