@@ -1,4 +1,4 @@
-# copyright 2016 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2016-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -12,7 +12,7 @@
 # details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
+# along with this program. If not, see <https://www.gnu.org/licenses/>.
 
 import base64
 from datetime import datetime
@@ -967,7 +967,8 @@ class EntityMapperTC(CubicWebTC):
             values = mapper.values(instance.copy())
             # All subject relations should appear in "values"
             subjrels = [rschema.type
-                        for rschema in entity.e_schema.subject_relations()
+                        for rschema in list(
+                                entity.e_schema.subject_relations.values())
                         if not rschema.meta]
             self.assertCountEqual(list(values), subjrels)
             self.assertEqual(values['data'].getvalue(), b'plip')
