@@ -1,4 +1,4 @@
-# copyright 2016 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2016-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -12,12 +12,10 @@
 # details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
+# along with this program. If not, see <https://www.gnu.org/licenses/>.
 
 """cubicweb-jsonschema Yams to jsl  unit tests."""
 
-from six import text_type
-
 from cubicweb.devtools.testlib import CubicWebTC
 
 from cubicweb_jsonschema.views.y2jsl import y2j_etype
@@ -26,7 +24,7 @@ from cubicweb_jsonschema.views.y2jsl import y2j_etype
 class CWYams2JsonTC(CubicWebTC):
 
     def rtype(self, etype, rtype):
-        return self.vreg.schema[etype].rdef(rtype)
+        return self.vreg.schema[etype].relation_definition(rtype)
 
     def test_auto_attributes(self):
         with self.admin_access.cnx() as cnx:
@@ -77,7 +75,7 @@ class CWYams2JsonTC(CubicWebTC):
                           'state_of'], list(state_props))
         expected_items = {
             'type': 'string',
-            'oneOf': [{'enum': [text_type(userworkflow_eid)],
+            'oneOf': [{'enum': [str(userworkflow_eid)],
                        'title': u'default user workflow'}],
         }
         self.assertEqual(state_props['state_of']['items'],
@@ -105,7 +103,7 @@ class CWYams2JsonTC(CubicWebTC):
         expected_items = {
             'type': 'string',
             'oneOf': [
-                {'enum': [text_type(eid)], 'title': title}
+                {'enum': [str(eid)], 'title': title}
                 for eid, title in users],
         }
         self.assertEqual(properties['in_group']['items'],
